<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 10/24/2009 *
 * ===================                          Last change: 06/20/2010 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : daily_profile.php                                *
 * -------------------------------------------------------------------- *
 * Short description : Sends out notifications to keep profiles updated *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Sendet Erinnerngen aus, damit die Profile        *
 *                     von den Mitgliedern aktuell gehalten werden      *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2012 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} elseif ((!isHtmlOutputMode()) || (!isResetModeEnabled())) {
	// Do not execute when script is in CSS mode or no daily reset
	return;
} elseif (!isExtensionActive('profile')) {
	logDebugMessage(__FILE__, __LINE__, 'Not resetting, needed extension disabled.');
	return;
}

// Debug line
//* DEBUG: */ logDebugMessage(__FILE__, __LINE__, 'Daily reset started.');

if ((isSendProfileUpdateEnabled()) && (getProfileUpdate() > 0) && (getResendProfileUpdate() > 0)) {
	// Load personal data
	$result = SQL_QUERY("SELECT
	`userid`,
	`email`,
	`last_update`,
	`joined`
FROM
	`{?_MYSQL_PREFIX?}_user_data`
WHERE
	`status`='CONFIRMED'
	" . runFilterChain('user_exclusion_sql', ' ') . " AND (
		(
			(UNIX_TIMESTAMP() - `last_update`) >= {?profile_update?} AND
			`last_update` > 0 AND
			(UNIX_TIMESTAMP() - `last_profile_sent`) >= {?resend_profile_update?}
		) OR (
			`last_update` = 0 AND
			`last_profile_sent` = 0 AND
			(UNIX_TIMESTAMP() - `joined`) >= {?profile_update?}
		)
	)
ORDER BY
	`userid` ASC", __FILE__, __LINE__);

	// Are there some notifications to sent?
	if (!SQL_HASZERONUMS($result)) {
		// We need to send-out notifications...
		while ($content = SQL_FETCHARRAY($result)) {
			// Translate timestamp
			$content['joined'] = generateDateTime($content['joined'], '0');

			if (round($content['last_update']) == '0') {
				// Has never changed his accont
				$content['last_update'] = '{--MEMBER_PROFILE_NEVER_CHANGED--}';
			} else {
				// Has changed his account
				$content['last_update'] = generateDateTime($content['last_update'], '0');
			}

			// Load email template and send mail away
			$message = loadEmailTemplate('member_profile', $content, bigintval($content['userid']));
			sendEmail($content['userid'], '{--MEMBER_PROFILE_OUTDATED_SUBJECT--}', $message);

			// Update profile data
			SQL_QUERY_ESC("UPDATE
	`{?_MYSQL_PREFIX?}_user_data`
SET
	`last_profile_sent`=UNIX_TIMESTAMP(),
	`notified`='Y'
WHERE
	`userid`=%s
LIMIT 1",
				array(bigintval($content['userid'])), __FILE__, __LINE__);
		} // END - while
	} // END - if

	// Free result
	SQL_FREERESULT($result);
} // END - if

// Debug line
//* DEBUG: */ logDebugMessage(__FILE__, __LINE__, 'Daily reset ended.');

// [EOF]
?>
